# Nipraxis

Tools for working with the [Nipraxis course](https://nipraxis.org)

## Install

```bash
pip install nipraxis
```

## Data

Data at <https://github.com/nipraxis/nipraxis-data/>

## Usage

```python
import nipraxis

fname = nipraxis.fetch_file('my_data_file.nii')
```
